vip\_hci.preproc package
========================

Submodules
----------

vip\_hci.preproc.badframes module
---------------------------------

.. automodule:: vip_hci.preproc.badframes
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.preproc.badpixremoval module
-------------------------------------

.. automodule:: vip_hci.preproc.badpixremoval
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.preproc.cosmetics module
---------------------------------

.. automodule:: vip_hci.preproc.cosmetics
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.preproc.derotation module
----------------------------------

.. automodule:: vip_hci.preproc.derotation
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.preproc.parangles module
---------------------------------

.. automodule:: vip_hci.preproc.parangles
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.preproc.recentering module
-----------------------------------

.. automodule:: vip_hci.preproc.recentering
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.preproc.rescaling module
---------------------------------

.. automodule:: vip_hci.preproc.rescaling
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.preproc.skysubtraction module
--------------------------------------

.. automodule:: vip_hci.preproc.skysubtraction
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.preproc.subsampling module
-----------------------------------

.. automodule:: vip_hci.preproc.subsampling
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: vip_hci.preproc
   :members:
   :undoc-members:
   :show-inheritance:
